==> 2.4.11.tar.gz: cloudlog/application/language/german/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['menu_badge_developer_mode'] = 'Entwickler-Modus';

$lang['menu_logbook'] = 'Logbuch';
$lang['menu_overview'] = 'Übersicht';
$lang['menu_advanced'] = 'Erweitert';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = 'Live QSO';
$lang['menu_post_qso'] = 'Zeitversetztes QSO';
$lang['menu_live_contest_logging'] = 'Live Contest Logging';
$lang['menu_post_contest_logging'] = 'Zeitversetztes Contest Logging';
$lang['menu_bandmap'] = 'Bandmap';
$lang['menu_view_qsl'] = 'QSL Ansicht';
$lang['menu_view_eqsl'] = 'eQSL Ansicht';

$lang['menu_notes'] = 'Notizen';

$lang['menu_analytics'] = 'Analysen';
$lang['menu_statistics'] = 'Statistik';
$lang['menu_gridsquares'] = 'Planquadrate';
$lang['menu_gridmap'] = 'Planquadratkarte';
$lang['menu_activated_gridsquares'] = 'Aktivierte Planquadrate';
$lang['menu_gridsquare_activators'] = 'Planquadrat-Aktivierer';
$lang['menu_distances_worked'] = 'Gearbeitete Entfernungen';
$lang['menu_days_with_qsos'] = 'Tage mit QSOs';
$lang['menu_timeline'] = 'Zeitleiste';
$lang['menu_accumulated_statistics'] = 'Kumulierte Statistiken';
$lang['menu_timeplotter'] = 'Zeitplotter';
$lang['menu_custom_maps'] = 'Benutzerdefinierte Karte';
$lang['menu_continents'] = 'Kontinente';

$lang['menu_awards'] = 'Auszeichnungen';
$lang['menu_cq'] = 'CQ';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Countys';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = 'Admin';
$lang['menu_user_account'] = 'Benutzerkonten';
$lang['menu_global_options'] = 'Globale Optionen';
$lang['menu_modes'] = 'Modi';
$lang['menu_contests'] = 'Conteste';
$lang['menu_themes'] = 'Layouts';
$lang['menu_backup'] = 'Backup';
$lang['menu_update_country_files'] = 'Update Länderinformationen';
$lang['menu_debug_information'] = 'Debug Informationen';

$lang['menu_search_text'] = 'Rufzeichensuche';

$lang['menu_search_button'] = 'Suche';
$lang['menu_login_button'] = 'Login';

$lang['menu_account'] = 'Konto';
$lang['menu_station_logbooks'] = 'Stationslogbücher';
$lang['menu_station_locations'] = 'Stationsstandorte';
$lang['menu_bands'] = 'Bänder';
$lang['menu_adif_import_export'] = 'ADIF Import / Export';
$lang['menu_kml_export'] = 'KML Export';
$lang['menu_dx_atlas_gridsquare_export'] = 'DX Atlas Planquadrat Export';
$lang['menu_sota_csv_export'] = 'SOTA CSV Export';
$lang['menu_cabrillo_export'] = 'Cabrillo Export';
$lang['menu_oqrs_requests'] = 'OQRS Anforderungen';
$lang['menu_print_requested_qsls'] = 'Druck angeforderter QSLs';
$lang['menu_labels'] = 'Etiketten';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'eQSL Import / Export';
$lang['menu_qrz_logbook'] = 'QRZ Logbuch';
$lang['menu_hrd_logbook'] = 'HRDLog Logbuch';
$lang['menu_qo_100_dx_club_upload'] = 'QO-100 Dx Club Upload';
$lang['menu_api_keys'] = 'API-Schlüssel';
$lang['menu_hardware_interfaces'] = 'Hardware-Schnittstellen';
$lang['menu_help'] = 'Hilfe';
$lang['menu_forum'] = 'Forum';
$lang['menu_logout'] = 'Logout';

$lang['menu_ffma'] = "Fred Fish Memorial Award";
$lang['menu_maintenance'] = 'Wartung';

==> 2.5.2.tar.gz: cloudlog/application/language/german/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['menu_badge_developer_mode'] = 'Entwickler-Modus';

$lang['menu_logbook'] = 'Logbuch';
$lang['menu_overview'] = 'Übersicht';
$lang['menu_advanced'] = 'Erweitert';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = 'Live QSO';
$lang['menu_post_qso'] = 'Zeitversetztes QSO';
$lang['menu_fast_log_entry'] = "Simple Fast Log Entry";
$lang['menu_live_contest_logging'] = 'Live Contest Logging';
$lang['menu_post_contest_logging'] = 'Zeitversetztes Contest Logging';
$lang['menu_bandmap'] = 'Bandmap';
$lang['menu_view_qsl'] = 'QSL Ansicht';
$lang['menu_view_eqsl'] = 'eQSL Ansicht';

$lang['menu_notes'] = 'Notizen';

$lang['menu_analytics'] = 'Analysen';
$lang['menu_statistics'] = 'Statistik';
$lang['menu_gridsquares'] = 'Planquadrate';
$lang['menu_gridmap'] = 'Planquadratkarte';
$lang['menu_activated_gridsquares'] = 'Aktivierte Planquadrate';
$lang['menu_gridsquare_activators'] = 'Planquadrat-Aktivierer';
$lang['menu_distances_worked'] = 'Gearbeitete Entfernungen';
$lang['menu_days_with_qsos'] = 'Tage mit QSOs';
$lang['menu_timeline'] = 'Zeitleiste';
$lang['menu_accumulated_statistics'] = 'Kumulierte Statistiken';
$lang['menu_timeplotter'] = 'Zeitplotter';
$lang['menu_custom_maps'] = 'Benutzerdefinierte Karte';
$lang['menu_continents'] = 'Kontinente';

$lang['menu_awards'] = 'Diplome';
$lang['menu_cq'] = 'CQ';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Counties';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = 'Admin';
$lang['menu_user_account'] = 'Benutzerkonten';
$lang['menu_global_options'] = 'Globale Optionen';
$lang['menu_modes'] = 'Modi';
$lang['menu_contests'] = 'Conteste';
$lang['menu_themes'] = 'Themes';
$lang['menu_backup'] = 'Backup';
$lang['menu_update_country_files'] = 'Update Länderinformationen';
$lang['menu_debug_information'] = 'Debug Informationen';

$lang['menu_search_text'] = 'Rufzeichensuche';
$lang['menu_search_text_quicklog'] = "Logge/Suche Call";   //"Rufzeichen" wäre zu lang, daher nur "Call". Das wird verstanden.

$lang['menu_search_button'] = 'Suche';
$lang['menu_search_button_qicksearch_log'] = "Logge";
$lang['menu_login_button'] = 'Login';

$lang['menu_account'] = 'Konto';
$lang['menu_station_logbooks'] = 'Stationslogbücher';
$lang['menu_station_locations'] = 'Stationsstandorte';
$lang['menu_bands'] = 'Bänder';
$lang['menu_adif_import_export'] = 'ADIF Import / Export';
$lang['menu_kml_export'] = 'KML Export';
$lang['menu_dx_atlas_gridsquare_export'] = 'DX Atlas Planquadrat Export';
$lang['menu_sota_csv_export'] = 'SOTA CSV Export';
$lang['menu_cabrillo_export'] = 'Cabrillo Export';
$lang['menu_oqrs_requests'] = 'OQRS Anforderungen';
$lang['menu_print_requested_qsls'] = 'Druck angeforderter QSLs';
$lang['menu_labels'] = 'Etiketten';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'eQSL Import / Export';
$lang['menu_qrz_logbook'] = 'QRZ Logbuch';
$lang['menu_hrd_logbook'] = 'HRDLog Logbuch';
$lang['menu_qo_100_dx_club_upload'] = 'QO-100 Dx Club Upload';
$lang['menu_api_keys'] = 'API-Schlüssel';
$lang['menu_hardware_interfaces'] = 'Hardware-Schnittstellen';
$lang['menu_help'] = 'Hilfe';
$lang['menu_forum'] = 'Forum';
$lang['menu_logout'] = 'Logout';

$lang['menu_ffma'] = "Fred Fish Memorial Award";
$lang['menu_ja_gridmaster'] = 'JA Gridmaster';
$lang['menu_maintenance'] = 'Wartung';
